@@ -1,15 +1,22 @@
-package App::ClusterSSH::Getopt;
-
 use strict;
 use warnings;
 
-use version;
-our $VERSION = version->new('0.01');
+package App::ClusterSSH::Getopt;
+$App::ClusterSSH::Getopt::VERSION = '4.14';
+# ABSTRACT: App::ClusterSSH::Getopt - module to process command line args
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+Object representing application configuration
+
+=cut
 
 use Carp;
 use Try::Tiny;
 use Pod::Usage;
-use Getopt::Long qw(:config no_ignore_case bundling no_auto_abbrev);
+use Getopt::Long 2.48 qw(:config no_ignore_case bundling no_auto_abbrev);
 use FindBin qw($Script);
 
 use base qw/ App::ClusterSSH::Base /;
@@ -18,7 +25,7 @@ sub new {
     my ( $class, %args ) = @_;
 
     # basic setup that is over-rideable by each script as needs may be
-    # different depending ont he command used
+    # different depending on the command used
     my %setup = (
         usage => [
             '-h|--help', '[options] [[user@]<server>[:port]|<tag>] [...] ',
@@ -126,7 +133,7 @@ sub add_common_options {
     $self->add_option(
         spec => 'debug:+',
         help => $self->loc(
-            "Enable debugging.  Either a level can be provided or the option can be repeated multiple times.  Maximum level is 4."
+            "Enable debugging.  Either a level can be provided or the option can be repeated multiple times.  Maximum level is 9."
         ),
         default => 0,
     );
@@ -145,7 +152,7 @@ sub add_common_options {
     $self->add_option(
         spec => 'autoquit|q',
         help => $self->loc(
-            'Toggle automatically quiting after the last client window has closed (overriding the config file).'
+            'Toggle automatically quitting after the last client window has closed (overriding the config file).'
         ),
     );
     $self->add_option(
@@ -240,6 +247,22 @@ sub add_common_options {
         help =>
             $self->loc('Do not output extra text when using some options'),
     );
+    $self->add_option(
+        spec     => 'cols|x=i',
+        arg_desc => 'cols',
+        help     => $self->loc('Number of columns'),
+    );
+    $self->add_option(
+        spec     => 'rows|y=i',
+        arg_desc => 'rows',
+        help     => $self->loc('Number of rows'),
+    );
+
+    $self->add_option(
+        spec => 'fillscreen',
+        help => $self->loc(
+            'Resize terminal windows to fill the whole available screen'),
+    );
 
     return $self;
 }
@@ -306,10 +329,14 @@ sub getopts {
     }
 
     $options->{debug} ||= 0;
-    $options->{debug} = 4 if ( $options->{debug} && $options->{debug} > 4 );
+    $options->{debug} = 9 if ( $options->{debug} && $options->{debug} > 9 );
 
     # Now all options are set to the correct values, generate accessor methods
     foreach my $option ( sort keys( %{ $self->{command_options} } ) ) {
+
+        # skip some accessors as they are already defined elsewhere
+        next if $option =~ m/^(debug)\W/;
+
         my $accessor = $self->{command_options}->{$option}->{accessor};
 
         my $default = $self->{command_options}->{$option}->{default};
@@ -333,7 +360,7 @@ sub getopts {
         }
     }
 
-    $self->set_debug_level( $self->debug );
+    $self->set_debug_level( $options->{debug} );
 
     $self->parent->config->load_configs( $self->config_file );
 
@@ -376,6 +403,14 @@ sub getopts {
             = !$self->parent->config->{window_tiling} || 0;
     }
 
+    if ( $self->rows ) {
+        $self->parent->config->{rows} = $self->rows;
+    }
+    if ( $self->cols ) {
+        $self->parent->config->{cols} = $self->cols;
+    }
+    $self->parent->config->{fillscreen} = "yes"
+        if ( $self->fillscreen );
     return $self;
 }
 
@@ -394,7 +429,10 @@ sub _generate_pod {
     output $/ , "=pod";
     output '=head1 ',    $self->loc('NAME');
     output "$Script - ", $self->loc("Cluster administration tool");
-    output '=head1 ',    $self->loc('SYNOPSIS');
+    output '=head1 ',    $self->loc('VERSION');
+    output $self->loc( "This documentation is for version: [_1]",
+        $self->parent->VERSION );
+    output '=head1 ', $self->loc('SYNOPSIS');
 
     # build the synopsis
     print "$Script ";
@@ -521,6 +559,14 @@ would replace the <Alt-n> with the client's name in each window.}
     output $self->loc(q{Retile all the client windows.});
     output '=item ', $self->parent->config->{key_username};
     output $self->loc(q{Paste in the username for the connection});
+    output '=item ', $self->parent->config->{key_user_1} || 'Alt-1';
+    output '=item ', $self->parent->config->{key_user_2} || 'Alt-2';
+    output '=item ', $self->parent->config->{key_user_3} || 'Alt-3';
+    output '=item ', $self->parent->config->{key_user_4} || 'Alt-4';
+    output $self->loc(
+        q{Run the matching user defined macro on the server and send the output to the client}
+    );
+
     output '=back';
 
     output '=head1 ' . $self->loc('EXAMPLES');
@@ -629,6 +675,11 @@ would replace the <Alt-n> with the client's name in each window.}
         'L<--autoquit>',
     );
 
+    output '=item auto_wm_decoration_offsets = no';
+    output $self->loc(
+        'Enable or disable alternative algorithm for calculating terminal positioning.',
+    );
+
     output '=item comms = ' . $self->parent->config->{comms};
     output $self->loc(
         'Sets the default communication method (initially taken from the name of the program, but can be overridden here).'
@@ -639,6 +690,22 @@ would replace the <Alt-n> with the client's name in each window.}
         q{Set the initial position of the console - if empty then let the window manager decide.  Format is '+<x>+<y>', i.e. '+0+0' is top left hand corner of the screen, '+0-70' is bottom left hand side of screen (more or less).}
     );
 
+    output '=item external_command_mode = 0600';
+    output $self->loc(q{File mode bits for the external_command_pipe.});
+
+    output '=item external_command_pipe = <null>';
+    output $self->loc(
+        q{Define the full path to an external command pipe that can be written to for controlling some aspects of ClusterSSH, such as opening sessions to more clusters.
+
+Commands:
+
+C<< open <tag|hostname> >> - open new sessions to provided tag or hostname
+
+C<< retile >> - force window retiling
+
+e.g.: C<< echo 'open localhost' >> /path/to/external_command_pipe >>}
+    );
+
     output '=item external_cluster_command = <null>';
     output $self->loc(
         q{Define the full path to an external command that can be used to resolve tags to host names.  This command can be written in any language.  The script must accept a list of tags to resolve and output a list of hosts (space separated on a single line).  Any tags that cannot be resolved should be returned unchanged.
@@ -709,15 +776,64 @@ If the external command is given a C<-L> option it should output a list of tags
         'L<KEY SHORTCUTS>'
     );
 
+    output '=item key_user_1 = Alt-1';
+    output '=item key_user_2 = Alt-2';
+    output '=item key_user_3 = Alt-3';
+    output '=item key_user_4 = Alt-4';
+    output $self->loc(
+        q{Default key sequence to send user defined macros to client.  If the matching [_2] macro is undefined, the sequence is passed straight to the terminal.  See [_1] for more information.},
+        'L<KEY SHORTCUTS>',
+        'L<macro_user_1>'
+    );
+
     output '=item macro_servername = %s';
     output '=item macro_hostname = %h';
     output '=item macro_username = %u';
     output '=item macro_newline = %n';
     output '=item macro_version = %v';
+    output '=item macro_user_1 = %1';
+    output '=item macro_user_2 = %2';
+    output '=item macro_user_3 = %3';
+    output '=item macro_user_4 = %4';
     output $self->loc(
         q{Change the replacement macro used when either using a 'Send' menu item, or when pasting text into the main console.}
     );
 
+    output '=item macro_user_1_command =';
+    output '=item macro_user_2_command =';
+    output '=item macro_user_3_command =';
+    output '=item macro_user_4_command =';
+
+    output $self->loc(
+        q{User defined macros - the macro is run through the shell on the server and the output is sent to the client.  For example,},
+    );
+
+    output "C<macro_user_1_command=echo echo macro_user_1>";
+    output $self->loc(
+        q{
+            would send the text [_1] into the terminal session.
+        },
+        'C<echo macro_user_1>'
+    );
+    output "C<macro_user_1_command=env | grep CSSH>";
+    output $self->loc(
+        q{
+            would send the CSSH environment variables to the client.
+        },
+    );
+
+    output $self->loc(
+        "The following environment variables are set in the shell of the macro process"
+    );
+    output '=over';
+    output '=item C<CSSH_SERVERNAME>';
+    output '=item C<CSSH_HOSTNAME>';
+    output '=item C<CSSH_USERNAME>';
+    output '=item C<CSSH_CONNECTION_STRING>';
+    output '=item C<CSSH_CONNECTION_PORT>';
+    output '=item C<CSSH_VERSION>';
+    output '=back';
+
     output '=item macros_enabled = yes';
     output $self->loc(
         q{Enable or disable macro replacement.  Note: this affects all the [_1] variables above.},
@@ -962,9 +1078,8 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
     );
     output '=back';
 
-    output '=head1 ', $self->loc('REPORTING BUGS');
-    output '=over';
-    output '=item *';
+    output '=head1 ', $self->loc('TROUBLESHOOTING');
+
     output $self->loc(
         q{If you have issues running [_1], first try:
 
@@ -985,16 +1100,16 @@ This performs two tests to confirm cssh is able to work properly with the settin
         $self->parent->config->{comms} );
     output '=back';
 
-    output $self->loc(q{Configuration options to watch for in ssh are});
+    output $self->loc(q{Configuration options to watch for in ssh are:});
     output '=over';
-    output '=item ',
-        $self->loc(
+    output '=item *';
+    output $self->loc(
         q{SSH doesn't understand [_1] - remove the option from the [_2] file},
         'C<-o ConnectTimeout=10>',
         'F<$HOME/.clusterssh/config>'
-        );
-    output '=item ',
-        $self->loc(
+    );
+    output '=item *';
+    output $self->loc(
         q{OpenSSH-3.8 using untrusted ssh tunnels - use [_1] instead of [_2] or use [_3] in [_4] (if you change the default ssh options from [_5] to [_6])},
         'C<-Y>',
         'C<-X>',
@@ -1002,12 +1117,19 @@ This performs two tests to confirm cssh is able to work properly with the settin
         'F<$HOME/.ssh/ssh_config>',
         'C<-x>',
         'C<-X>'
-        );
+    );
     output '=back';
 
-    output '=item *';
+    output '=head1 ', $self->loc('SUPPORT AND REPORTING BUGS');
+
     output $self->loc(
-        q{If you require support, please run the following commands and post it on the web site in the support/problems forum:}
+        q{A web site for comments, requests, bug reports and bug fixes/patches is available at: [_1]},
+        'L<https://github.com/duncs/clusterssh>'
+    );
+
+    output $self->loc(
+        q{If you require support, please run the following commands and create an issue via: [_1]},
+        'L<https://github.com/duncs/clusterssh/issues>',
     );
     output 'C<< perl -V >>';
     output q{C<< perl -MTk -e 'print $Tk::VERSION,$/' >>};
@@ -1015,35 +1137,27 @@ This performs two tests to confirm cssh is able to work properly with the settin
         q{C<< perl -MX11::Protocol -e 'print $X11::Protocol::VERSION,$/' >>};
     output 'C<< cat /etc/csshrc $HOME/.clusterssh/config >>';
 
-    output '=item *';
     output $self->loc(
         q{Using the debug option (--debug) will turn on debugging output.  Repeat the option to increase the amount of debug.  However, if possible please only use this option with one host at a time, e.g. [_1] due to the amount of output produced (in both main and child windows).},
         'C<< cssh --debug <host> >>'
     );
-    output '=back';
 
     output '=head1 ', $self->loc('SEE ALSO');
     output $self->loc(
-        q{L<http://clusterssh.sourceforge.net/>,
+        q{L<https://github.com/duncs/clusterssh/wiki/>,
 C<ssh>,
 L<Tk::overview>,
 L<X11::Protocol>,
 C<perl>}
     );
 
-    output '=head1 ', $self->loc('CREDITS');
-    output $self->loc(
-        'A web site for comments, requests, bug reports and bug fixes/patches is available at: [_1]',
-        'L<https://github.com/duncs/clusterssh>'
-    );
-
     output '=head1 ', $self->loc('AUTHOR');
     output 'Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>';
 
     output '=head1 ', $self->loc('LICENSE AND COPYRIGHT');
     output $self->loc(
         q{
-Copyright 1999-2015 Duncan Ferguson.
+Copyright 1999-2018 Duncan Ferguson.
 
 This program is free software; you can redistribute it and/or modify it under the terms of either: the GNU General Public License as published by the Free Software Foundation; or the Artistic License.
 
@@ -1056,20 +1170,6 @@ See http://dev.perl.org/licenses/ for more information.
 
 1;
 
-__DATA__
-
-=pod
-
-=head1 NAME
-
-App::ClusterSSH::Getopt - module to process command line args
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-Object representing application configuration
-
 =head1 METHODS
 
 =over 4
@@ -1084,17 +1184,17 @@ Add extra options into the allowed set for parsing from the command line
 
 =item $obj=ClusterSSH::Getopts->add_common_options ({ })
 
-Add common options used by most calling scripts into the allowed set for 
+Add common options used by most calling scripts into the allowed set for
 parsing from the command line
 
 =item $obj=ClusterSSH::Getopts->add_common_session_options ({ })
 
-Add common session options used by most calling scripts into the allowed 
+Add common session options used by most calling scripts into the allowed
 set for parsing from the command line
 
 =item $obj=ClusterSSH::Getopts->add_common_ssh_options ({ })
 
-Add common ssh options used by most calling scripts into the allowed 
+Add common ssh options used by most calling scripts into the allowed
 set for parsing from the command line
 
 =item $obj->getopts
@@ -1113,21 +1213,3 @@ Simple helper func to print out pod lines with double returns
 Functions to output help and usage instructions
 
 =back
-
-=head1 AUTHOR
-
-Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 1999-2015 Duncan Ferguson.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
-
-=cut
-
-1;
