@@ -1,10 +1,17 @@
-package App::ClusterSSH::Helper;
-
 use strict;
 use warnings;
 
-use version;
-our $VERSION = version->new('0.02');
+package App::ClusterSSH::Helper;
+$App::ClusterSSH::Helper::VERSION = '4.14';
+# ABSTRACT: ClusterSSH::Helper - Object representing helper script
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+Object representing application configuration
+
+=cut
 
 use Carp;
 use Try::Tiny;
@@ -120,18 +127,6 @@ sub script {
 
 1;
 
-=pod
-
-=head1 NAME
-
-ClusterSSH::Helper - Object representing helper script
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-Object representing application configuration
-
 =head1 METHODS
 
 =over 4
@@ -145,21 +140,3 @@ Create a new helper object.
 Return the helper script
 
 =back
-
-=head1 AUTHOR
-
-Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 1999-2016 Duncan Ferguson.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
-
-=cut
-
-1;
