@@ -2,8 +2,7 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Window;
-$App::ClusterSSH::Window::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Window::VERSION = '4.1806';
+$App::ClusterSSH::Window::VERSION = '4.14';
 # ABSTRACT: App::ClusterSSH::Window - Base obejct for different types of window module
 
 =head1 DESCRIPTION
@@ -29,12 +28,8 @@ sub import {
     my ($class) = @_;
 
     # If we are building or in test here, just exit
-    # as the build servers will not have Tk installed
-    if ( $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING} ) {
-        print STDERR
-            "skipping initialisation; AUTHOR_TESTING or RELEASE_TESTING are set\n";
-        return;
-    }
+    # as travis build servers will not have Tk installed
+    return if $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING};
 
     # Find what windows module we should be using and just overlay it into
     # this object
