@@ -2,8 +2,7 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Window::Tk;
-$App::ClusterSSH::Window::Tk::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Window::Tk::VERSION = '4.1806';
+$App::ClusterSSH::Window::Tk::VERSION = '4.14';
 # ABSTRACT: Object for creating windows using Tk
 
 use English qw( -no_match_vars );
@@ -11,8 +10,8 @@ use English qw( -no_match_vars );
 use base qw/ App::ClusterSSH::Base /;
 use vars qw/ %keysymtocode %keycodetosym /;
 
-use Sys::Hostname qw/ hostname /;
-use File::Temp    qw/:POSIX/;
+use Net::Domain qw(hostfqdn);
+use File::Temp qw/:POSIX/;
 use Fcntl;
 use POSIX ":sys_wait_h";
 use POSIX qw/:sys_wait_h strftime mkfifo/;
@@ -28,14 +27,14 @@ use X11::Protocol::Constants qw/ Shift Mod5 ShiftMask /;
 use X11::Protocol::WM 29;
 use X11::Keysyms '%keysymtocode', 'MISCELLANY', 'XKB_KEYS', '3270', 'LATIN1',
     'LATIN2', 'LATIN3', 'LATIN4', 'KATAKANA', 'ARABIC', 'CYRILLIC', 'GREEK',
-    'TECHNICAL', 'SPECIAL', 'PUBLISHING', 'APL', 'HEBREW', 'THAI',  'KOREAN';
+    'TECHNICAL', 'SPECIAL', 'PUBLISHING', 'APL', 'HEBREW', 'THAI', 'KOREAN';
 
 # Module to contain all Tk specific functionality
 
-my %windows;                   # hash for all window definitions
-my %menus;                     # hash for all menu definitions
-my @servers;                   # array of servers provided on cmdline
-my %servers;                   # hash of server cx info
+my %windows;    # hash for all window definitions
+my %menus;      # hash for all menu definitions
+my @servers;    # array of servers provided on cmdline
+my %servers;    # hash of server cx info
 my $xdisplay;
 my %keyboardmap;
 my $sysconfigdir = "/etc";
@@ -81,15 +80,6 @@ sub pick_color {
     return $ans;
 }
 
-# Return list of host keys in display order (command-line order if
-# preserve_host_order, else sorted)
-sub _hosts_in_display_order {
-    my ($self) = @_;
-    return grep { exists $servers{$_} } @servers
-        if ( $self->config->{preserve_host_order} );
-    return $self->sort->( keys(%servers) );
-}
-
 # close a specific host session
 sub terminate_host($) {
     my ( $self, $svr ) = @_;
@@ -190,14 +180,13 @@ sub open_client_windows(@) {
         }
         $server .= q{ } . $count;
 
-        push( @servers, $server );
         $servers{$server}{connect_string} = $_;
         $servers{$server}{givenname}      = $given_server_name;
         $servers{$server}{realname}       = $realname;
         $servers{$server}{username}       = $self->config->{user};
         $servers{$server}{username}       = $username if ($username);
-        $servers{$server}{username}       = $username             || '';
-        $servers{$server}{port}           = $port                 || '';
+        $servers{$server}{username}       = $username || '';
+        $servers{$server}{port}           = $port || '';
         $servers{$server}{master}         = $self->config->{mstr} || '';
         $servers{$server}{master}         = $master if ($master);
 
@@ -325,8 +314,6 @@ sub set_half_inactive() {
     my ($self) = @_;
     $self->debug( 2, "Setting approx half of all hosts to inactive" );
 
-    return if !%servers;
-
     my (@keys) = keys(%servers);
     $#keys /= 2;
     foreach my $svr (@keys) {
@@ -359,8 +346,7 @@ sub add_host_by_name() {
     if ( $menus{host_entry} ) {
         $self->debug( 2, "host=", $menus{host_entry} );
         my @names
-            = $self->parent->resolve_names(
-            split( /\s+/, $menus{host_entry} ) );
+            = $self->resolve_names( split( /\s+/, $menus{host_entry} ) );
         $self->debug( 0, 'Opening to: ', join( ' ', @names ) ) if (@names);
         $self->open_client_windows(@names);
     }
@@ -368,7 +354,7 @@ sub add_host_by_name() {
     if ( defined $menus{listbox} && $menus{listbox}->curselection() ) {
         my @hosts = $menus{listbox}->get( $menus{listbox}->curselection() );
         $self->debug( 2, "host=", join( ' ', @hosts ) );
-        $self->open_client_windows( $self->parent->resolve_names(@hosts) );
+        $self->open_client_windows( $self->resolve_names(@hosts) );
     }
 
     $self->build_hosts_menu();
@@ -447,9 +433,8 @@ sub load_keyboard_map() {
 
                 # keyboard layout contains the keycode at $modifier level
                 if (defined(
-                        $keyboardmap{
-                            $keycodetosym{ $keyboard[$i][$modifier] }
-                        }
+                        $keyboardmap{ $keycodetosym{ $keyboard[$i][$modifier]
+                        } }
                     )
                     )
                 {
@@ -614,7 +599,7 @@ sub substitute_macros {
     }
     {
         my $macro_hostname = $self->config->{macro_hostname};
-        my $hostname       = $self->config->{hostname_override} || hostname();
+        my $hostname       = hostfqdn();
         $text =~ s!$macro_hostname!$hostname!xsmg;
         $ENV{CSSH_HOSTNAME} = $hostname;
     }
@@ -1033,7 +1018,7 @@ sub retile_hosts {
     my ( $current_x, $current_y, $current_row, $current_col ) = 0;
     if ( $self->config->{window_tiling_direction} =~ /right/i ) {
         $self->debug( 2, "Tiling top left going bot right" );
-        @hosts     = $self->_hosts_in_display_order();
+        @hosts     = $self->sort->( keys(%servers) );
         $current_x = $self->config->{screen_reserve_left}
             + $self->config->{terminal_reserve_left};
         $current_y = $self->config->{screen_reserve_top}
@@ -1043,7 +1028,7 @@ sub retile_hosts {
     }
     else {
         $self->debug( 2, "Tiling bot right going top left" );
-        @hosts = reverse( $self->_hosts_in_display_order() );
+        @hosts = reverse( $self->sort->( keys(%servers) ) );
         $current_x
             = $self->config->{screen_reserve_right}
             - $self->config->{internal_screen_width}
@@ -1166,7 +1151,7 @@ sub build_hosts_menu() {
     $self->debug( 3, "Parsing list" );
 
     my $menu_item_counter = $host_menu_static_items;
-    foreach my $svr ( $self->_hosts_in_display_order() ) {
+    foreach my $svr ( $self->sort->( keys(%servers) ) ) {
         $self->debug( 3, "Checking $svr and restoring active value" );
         my $colbreak = 0;
         if ( $menu_item_counter > $self->config->{max_host_menu_items} ) {
@@ -1219,8 +1204,7 @@ sub setup_repeat() {
 
                         for ($cmd) {
                             if (m/^open$/) {
-                                my @new_hosts
-                                    = $self->parent->resolve_names(@tags);
+                                my @new_hosts = $self->resolve_names(@tags);
                                 $self->open_client_windows(@new_hosts);
                                 $self->build_hosts_menu();
                                 last;
@@ -1291,22 +1275,11 @@ sub setup_repeat() {
 ### Window and menu definitions ###
 
 sub create_windows() {
-    my ($self)          = @_;
-    my ($screen_height) = $xdisplay->{height_in_pixels};
-    my ($screen_width)  = $xdisplay->{width_in_pixels};
+    my ($self) = @_;
     $self->debug( 2, "create_windows: started" );
 
     $windows{main_window}
         = MainWindow->new( -title => "ClusterSSH", -class => 'cssh', );
-    if ( $self->config->{main_window_font} ) {
-        $windows{main_window}
-            ->optionAdd( '*font', $self->config->{main_window_font} );
-    }
-    elsif ( $screen_height * $screen_width >= 8294400 )
-    {    # display 4k or bigger
-        $windows{main_window}->optionAdd( '*font', 'Nimbus 14' )
-            ;    # better for 4k displays
-    }
     $windows{main_window}->withdraw;    # leave withdrawn until needed
 
     if ( defined( $self->config->{console_position} )
@@ -1371,16 +1344,10 @@ sub create_windows() {
             $menus{entrytext} = "";
             my $paste_text = '';
 
-# SelectionGet is fatal if no selection is given; try PRIMARY then CLIPBOARD (Wayland/WSLg use CLIPBOARD)
+            # SelectionGet is fatal if no selection is given
             Tk::catch {
                 $paste_text = $windows{main_window}->SelectionGet;
             };
-            if ( !length($paste_text) ) {
-                Tk::catch {
-                    $paste_text = $windows{main_window}
-                        ->SelectionGet( -selection => 'CLIPBOARD' );
-                };
-            }
 
             if ( !length($paste_text) ) {
                 warn("Got empty paste event\n");
@@ -1591,7 +1558,7 @@ sub key_event {
     my $keycode   = $Tk::event->k;
     my $keysymdec = $Tk::event->N;
     my $keysym    = $Tk::event->K;
-    my $state     = $Tk::event->s || 0;
+    my $state = $Tk::event->s || 0;
 
     $menus{entrytext} = "";
 
